@@ -5,7 +5,7 @@
 #' analyses not requiring a 2-by-2 table as input (selection bias analysis `selection`,
 #' bias analysis for unmeasured confounder `confounders`, bias analysis for unmeasured
 #' 3-level confounder `confounders.poly`, bias analysis for unmeasured confounder with
-#' effect modification `confounders.emm`, misclassification bias analysis `misclassification`,
+#' effect modification `confounders.emm`, misclassification bias analysis `misclass`,
 #' and multidimensional sensitivity analysis `multidimBias`).
 #'
 #' @param id shiny id
@@ -401,9 +401,9 @@ mod_analysis_server <- function(input, output, session) {
                                                              alpha = input$alpha
                                                              )
                                } else if (input$type == "misclass") {
-                                   episensr::misclassification(mat,
-                                                               type = input$misclass_type,
-                                                               bias_parms = c(callModule(mod_parms_server, "parms_mis1"),
+                                   episensr::misclass(mat,
+                                                      type = input$misclass_type,
+                                                      bias_parms = c(callModule(mod_parms_server, "parms_mis1"),
                                                                               callModule(mod_parms_server, "parms_mis2"),
                                                                               callModule(mod_parms_server, "parms_mis3"),
                                                                               callModule(mod_parms_server, "parms_mis4")),
@@ -438,32 +438,32 @@ mod_analysis_server <- function(input, output, session) {
                                  })
 
     shinyjs::runjs("document.getElementById('help_selection').onclick = function() {
-           window.open('https://dhaine.github.io/episensr/reference/selection.html', '_blank');
+           window.open('https://dhaine.codeberg.page/episensr/reference/selection.html', '_blank');
          };"
          )
 
     shinyjs::runjs("document.getElementById('help_confounder').onclick = function() {
-           window.open('https://dhaine.github.io/episensr/reference/confounders.html', '_blank');
+           window.open('https://dhaine.codeberg.page/episensr/reference/confounders.html', '_blank');
          };"
          )
 
     shinyjs::runjs("document.getElementById('help_confounder3').onclick = function() {
-           window.open('https://dhaine.github.io/episensr/reference/confounders.poly.html', '_blank');
+           window.open('https://dhaine.codeberg.page/episensr/reference/confounders.html', '_blank');
          };"
          )
 
     shinyjs::runjs("document.getElementById('help_confounderemm').onclick = function() {
-           window.open('https://dhaine.github.io/episensr/reference/confounders.emm.html', '_blank');
+           window.open('https://dhaine.codeberg.page/episensr/reference/confounders.html', '_blank');
          };"
          )
 
     shinyjs::runjs("document.getElementById('help_misclass').onclick = function() {
-           window.open('https://dhaine.github.io/episensr/reference/misclassification.html', '_blank');
+           window.open('https://dhaine.codeberg.page/episensr/reference/misclass.html', '_blank');
          };"
          )
 
         shinyjs::runjs("document.getElementById('help_multidim').onclick = function() {
-           window.open('https://dhaine.github.io/episensr/reference/multidimBias.html', '_blank');
+           window.open('https://dhaine.codeberg.page/episensr/reference/multidimBias.html', '_blank');
          };"
          )
 }
