@@ -187,7 +187,7 @@ mod_notable_server <- function(input, output, session) {
                                    episensr::confounders.limit(p = callModule(mod_parms3a_server, "parms_conflimit1"),
                                                                RR = callModule(mod_parms3b_server, "parms_conflimit2"),
                                                                OR = callModule(mod_parms3b_server, "parms_conflimit3"),
-                                                               crude.RR = callModule(mod_parms3b_server, "parms_conflimit4")
+                                                               crude_RR = callModule(mod_parms3b_server, "parms_conflimit4")
                                                                )
                                } else if (input$type == "confounder_ext") {
                                    episensr::confounders.ext(RR = callModule(mod_parms3b_server,
@@ -195,7 +195,7 @@ mod_notable_server <- function(input, output, session) {
                                                             bias_parms = c(callModule(mod_parms3b_server, "parms_confext1"), callModule(mod_parms3b_server, "parms_confext2"), callModule(mod_parms3c_server, "parms_confext3"), callModule(mod_parms3c_server, "parms_confext4")))
                                } else if (input$type == "confounder_array") {
                                    episensr::confounders.array(
-                                                 crude.risk = callModule(mod_parms3_server,
+                                                 crude_risk = callModule(mod_parms3_server,
                                                                          "parms_confarray0"),
                                                  type = input$parms_confarray1,
                                                  bias_parms = c(callModule(mod_parms3_server, "parms_confarray2"), callModule(mod_parms3_server, "parms_confarray3"), callModule(mod_parms3_server, "parms_confarray4"))
@@ -217,22 +217,22 @@ mod_notable_server <- function(input, output, session) {
                                           })
 
     shinyjs::runjs("document.getElementById('help_confarray').onclick = function() {
-           window.open('https://dhaine.github.io/episensr/reference/confounders.array.html', '_blank');
+           window.open('https://dhaine.codeberg.page/episensr/reference/confounders.array.html', '_blank');
          };"
          )
 
     shinyjs::runjs("document.getElementById('help_confext').onclick = function() {
-           window.open('https://dhaine.github.io/episensr/reference/confounders.ext.html', '_blank');
+           window.open('https://dhaine.codeberg.page/episensr/reference/confounders.ext.html', '_blank');
          };"
          )
 
     shinyjs::runjs("document.getElementById('help_conflimit').onclick = function() {
-           window.open('https://dhaine.github.io/episensr/reference/confounders.limit.html', '_blank');
+           window.open('https://dhaine.codeberg.page/episensr/reference/confounders.limit.html', '_blank');
          };"
          )
 
     shinyjs::runjs("document.getElementById('help_mbias').onclick = function() {
-           window.open('https://dhaine.github.io/episensr/reference/mbias.html', '_blank');
+           window.open('https://dhaine.codeberg.page/episensr/reference/mbias.html', '_blank');
          };"
   )
 }
